@@ -13,24 +13,24 @@ use vars qw/$dbh/;
 my $path = abs_path( File::Spec->catdir( $FindBin::Bin, '..' ) );
 
 print "You are going to configure Foorum for your own using.\n",
-    "=" x 50,
+    '=' x 50,
     "\nPlease report bugs to AUTHORS if u meet any problem.\n\n";
 
 my $foorum_local_file = File::Spec->catfile( $path, 'foorum_local.yml' );
-print "We are saving your configure to ", "$foorum_local_file\n",
+print 'We are saving your configure to ', "$foorum_local_file\n",
     "You can change it by a plain editor (Notepad or Vi) later\n\n";
 
 DBI:
 
 # options
-print "Which Database are u used for Foorum (MySQL, SQLite, Pg): ";
+print 'Which Database are u used for Foorum (MySQL, SQLite, Pg): ';
 my $db_type;
 while ( $db_type = <> ) {
     chomp($db_type);
-    if ( $db_type eq 'MySQL' or $db_type eq 'SQLite' or $db_type eq 'Pg' ) {
+    if ( 'MySQL' eq $db_type or 'SQLite' eq $db_type or 'Pg' eq $db_type ) {
         last;
     } else {
-        print "Which Database are u used for Foorum (MySQL, SQLite, Pg): ";
+        print 'Which Database are u used for Foorum (MySQL, SQLite, Pg): ';
     }
 }
 
@@ -41,7 +41,7 @@ $dns_host = 'localhost' unless ($dns_host);
 
 # SQLite don't require user and password
 my ( $dns_user, $dns_password ) = ( '', '' );
-if ( $db_type eq 'MySQL' or $db_type eq 'Pg' ) {
+if ( 'MySQL' eq $db_type or 'Pg' eq $db_type ) {
     print "Your $db_type user (root by default): ";
     $dns_user = <>;
     chomp($dns_user);
@@ -52,11 +52,11 @@ if ( $db_type eq 'MySQL' or $db_type eq 'Pg' ) {
     chomp($dns_password);
 }
 
-$db_type = lc($db_type) if ( $db_type eq 'MySQL' );
+$db_type = lc($db_type) if ( 'MySQL' eq $db_type );
 my $dns = "dbi:$db_type:database=foorum;host=$dns_host;port=3306";
 my $theschwartz_dsn
     = "dbi:$db_type:database=theschwartz;host=$dns_host;port=3306";
-if ( $db_type eq 'SQLite' ) {
+if ( 'SQLite' eq $db_type ) {
     $dns             = "dbi:$db_type:$dns_host";
     $theschwartz_dsn = $dns;
 }
@@ -72,7 +72,7 @@ if ($@) {
 }
 
 print "Set your site domain which will be used in cron email.\n";
-print "Your site domain (http://www.foorumbbs.com/ by default): ";
+print 'Your site domain (http://www.foorumbbs.com/ by default): ';
 my $domain = <>;
 chomp($domain);
 $domain = 'http://www.foorumbbs.com/' unless ($domain);
@@ -97,6 +97,6 @@ print "Attention! The first user created will be site admin automatically!\n";
 my $sql
     = q~INSERT INTO user_role (user_id, role, field) VALUES (1, 'admin', 'site')~;
 $dbh->do($sql) or die $DBI::errstr;
-print "[OK] ", $sql, "\n";
+print '[OK] ', $sql, "\n";
 
-print "=" x 50, "\nDone!\n", "Thanks For Join US!\n";
+print '=' x 50, "\nDone!\n", "Thanks For Join US!\n";
