@@ -18,7 +18,7 @@ use Catalyst qw/
     +Foorum::Plugin::FoorumUtils
     /;
 
-use Foorum::Version; our $VERSION = $Foorum::VERSION;
+our $VERSION = '1.000000';
 
 __PACKAGE__->config( { VERSION => $VERSION } );
 __PACKAGE__->config( 'config_file' => [ 'foorum.yml', 'foorum_local.yml' ] );
@@ -51,7 +51,7 @@ __PACKAGE__->config->{'Plugin::PageCache'}->{key_maker} = sub {
     $lang =~ s/\W+//isg;
     $c->languages( [$lang] );
 
-    return "/" . $c->req->path;
+    return '/' . $c->req->path;
 };
 
 1;
