@@ -2,7 +2,7 @@ package Foorum::ResultSet::Topic;
 
 use strict;
 use warnings;
-use Foorum::Version; our $VERSION = $Foorum::VERSION;
+our $VERSION = '1.000000';
 use base 'DBIx::Class::ResultSet';
 
 sub get {
@@ -34,27 +34,27 @@ sub get {
 
 sub get_topic_id_list {
     my ( $self, $forum_id ) = @_;
-    
+
     my $schema = $self->result_source->schema;
     my $cache  = $schema->cache();
 
     my $cache_key = "topic|get_topic_id_list|forum_id=$forum_id";
     my $cache_val = $cache->get($cache_key);
-    
+
     if ( defined $cache_val and ref $cache_val eq 'ARRAY' ) {
         return wantarray ? @$cache_val : $cache_val;
     }
-    
+
     # get from db and set cache
     my @all = $self->search(
         {   forum_id    => $forum_id,
             'me.status' => { '!=', 'banned' },
-        }, {
-            order_by => \'sticky DESC, last_update_date DESC', #'
+        },
+        {   order_by => \'sticky DESC, last_update_date DESC',    #'
             columns  => ['topic_id'],
         }
     )->all;
-    
+
     my @topic_ids = map { $_->topic_id } @all;
     $cache->set( $cache_key, \@topic_ids, 1800 );
     return wantarray ? @topic_ids : \@topic_ids;
@@ -66,7 +66,8 @@ sub create_topic {
     my $schema = $self->result_source->schema;
 
     $create->{post_on} = time() unless ( $create->{post_on} );
-    $create->{last_update_date} = time() unless ( $create->{last_update_date} );
+    $create->{last_update_date} = time()
+        unless ( $create->{last_update_date} );
     my $topic = $self->create($create);
 
     # star it by default
@@ -157,7 +158,7 @@ sub remove {
     my $last_post_id = $lastest ? $lastest->topic_id : 0;
     $schema->resultset('Forum')->update_forum(
         $forum_id,
-        {   total_topics  => \"total_topics - 1",
+        {   total_topics  => \'total_topics - 1',
             last_post_id  => $last_post_id,
             total_replies => \"total_replies - $total_replies",
         }
