@@ -2,7 +2,7 @@ package Foorum::TheSchwartz::Worker::SendScheduledEmail;
 
 use strict;
 use warnings;
-use Foorum::Version; our $VERSION = $Foorum::VERSION;
+our $VERSION = '1.000000';
 use base qw( MooseX::TheSchwartz::Worker );
 use Foorum::SUtils qw/schema/;
 use Foorum::Logger qw/error_log/;
@@ -70,7 +70,7 @@ sub send_email {
 
     my $top = MIME::Entity->build(
         'X-Mailer' => undef,                   # remove X-Mailer tag in header
-        'Type'     => "multipart/alternative",
+        'Type'     => 'multipart/alternative',
         'Reply-To' => $from,
         'From'     => $from,
         'To'       => $to,
